Class: Aws::CodeGuruSecurity::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CodeGuruSecurity::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-codegurusecurity/client.rb,
sig/client.rbs
Overview
An API client for CodeGuruSecurity. To construct a client, you need to configure a :region and :credentials.
client = Aws::CodeGuruSecurity::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchGetFindingsResponseSuccess, _CreateScanResponseSuccess, _CreateUploadUrlResponseSuccess, _GetAccountConfigurationResponseSuccess, _GetFindingsResponseSuccess, _GetMetricsSummaryResponseSuccess, _GetScanResponseSuccess, _ListFindingsMetricsResponseSuccess, _ListScansResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAccountConfigurationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsResponse
Returns a list of requested findings from standard scans.
-
#create_scan(params = {}) ⇒ Types::CreateScanResponse
Use to create a scan using code uploaded to an Amazon S3 bucket.
-
#create_upload_url(params = {}) ⇒ Types::CreateUploadUrlResponse
Generates a pre-signed URL, request headers used to upload a code resource, and code artifact identifier for the uploaded resource.
-
#get_account_configuration(params = {}) ⇒ Types::GetAccountConfigurationResponse
Use to get the encryption configuration for an account.
-
#get_findings(params = {}) ⇒ Types::GetFindingsResponse
Returns a list of all findings generated by a particular scan.
-
#get_metrics_summary(params = {}) ⇒ Types::GetMetricsSummaryResponse
Returns a summary of metrics for an account from a specified date, including number of open findings, the categories with most findings, the scans with most open findings, and scans with most open critical findings.
-
#get_scan(params = {}) ⇒ Types::GetScanResponse
Returns details about a scan, including whether or not a scan has completed.
-
#list_findings_metrics(params = {}) ⇒ Types::ListFindingsMetricsResponse
Returns metrics about all findings in an account within a specified time range.
-
#list_scans(params = {}) ⇒ Types::ListScansResponse
Returns a list of all scans in an account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of all tags associated with a scan.
-
#tag_resource(params = {}) ⇒ Struct
Use to add one or more tags to an existing scan.
-
#untag_resource(params = {}) ⇒ Struct
Use to remove one or more tags from an existing scan.
-
#update_account_configuration(params = {}) ⇒ Types::UpdateAccountConfigurationResponse
Use to update the encryption configuration for an account.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-codegurusecurity/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1162 1163 1164 |
# File 'lib/aws-sdk-codegurusecurity/client.rb', line 1162 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1165 1166 1167 |
# File 'lib/aws-sdk-codegurusecurity/client.rb', line 1165 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_get_findings(params = {}) ⇒ Types::BatchGetFindingsResponse
Returns a list of requested findings from standard scans.
87 |
# File 'sig/client.rbs', line 87
def batch_get_findings: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 |
# File 'lib/aws-sdk-codegurusecurity/client.rb', line 1135 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CodeGuruSecurity') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-codegurusecurity' context[:gem_version] = '1.47.0' Seahorse::Client::Request.new(handlers, context) end |
#create_scan(params = {}) ⇒ Types::CreateScanResponse
Use to create a scan using code uploaded to an Amazon S3 bucket.
106 |
# File 'sig/client.rbs', line 106
def create_scan: (
|
#create_upload_url(params = {}) ⇒ Types::CreateUploadUrlResponse
Generates a pre-signed URL, request headers used to upload a code resource, and code artifact identifier for the uploaded resource.
You can upload your code resource to the URL with the request headers using any HTTP client.
125 |
# File 'sig/client.rbs', line 125
def create_upload_url: (
|
#get_account_configuration(params = {}) ⇒ Types::GetAccountConfigurationResponse
Use to get the encryption configuration for an account.
135 |
# File 'sig/client.rbs', line 135
def get_account_configuration: (
|
#get_findings(params = {}) ⇒ Types::GetFindingsResponse
Returns a list of all findings generated by a particular scan.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
145 |
# File 'sig/client.rbs', line 145
def get_findings: (
|
#get_metrics_summary(params = {}) ⇒ Types::GetMetricsSummaryResponse
Returns a summary of metrics for an account from a specified date, including number of open findings, the categories with most findings, the scans with most open findings, and scans with most open critical findings.
158 |
# File 'sig/client.rbs', line 158
def get_metrics_summary: (
|
#get_scan(params = {}) ⇒ Types::GetScanResponse
Returns details about a scan, including whether or not a scan has completed.
176 |
# File 'sig/client.rbs', line 176
def get_scan: (
|
#list_findings_metrics(params = {}) ⇒ Types::ListFindingsMetricsResponse
Returns metrics about all findings in an account within a specified time range.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
188 |
# File 'sig/client.rbs', line 188
def list_findings_metrics: (
|
#list_scans(params = {}) ⇒ Types::ListScansResponse
Returns a list of all scans in an account. Does not return EXPRESS
scans.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
202 |
# File 'sig/client.rbs', line 202
def list_scans: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of all tags associated with a scan.
213 |
# File 'sig/client.rbs', line 213
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Use to add one or more tags to an existing scan.
222 |
# File 'sig/client.rbs', line 222
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Use to remove one or more tags from an existing scan.
232 |
# File 'sig/client.rbs', line 232
def untag_resource: (
|
#update_account_configuration(params = {}) ⇒ Types::UpdateAccountConfigurationResponse
Use to update the encryption configuration for an account.
243 |
# File 'sig/client.rbs', line 243
def update_account_configuration: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1155 1156 1157 |
# File 'lib/aws-sdk-codegurusecurity/client.rb', line 1155 def waiter_names [] end |